ChatApp class

Properties

archiveHandler ↔ ArchiveHandler
getter/setter pair
clientHandler ↔ ClientHandler
getter/setter pair
eventsSender ↔ ChatEventsSender
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invitationHandler ↔ InvitationHandler
getter/setter pair
messageReader ↔ MessageGlobalReader
getter/setter pair
messageSender ↔ MessageSender
getter/setter pair
mucHandler ↔ MucHandler
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disconnect() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

instance() → ChatApp?