ClientHandler class abstract

Implementers

Constructors

ClientHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allMessagesStream() → Stream<PayloadWithTopic>
connect({required dynamic host, required String username, required String password, String? clientId, int? port}) → Future<bool>
connectionStateStream() → Stream<ConnectionState>
disconnect() → void
getClientId() → String?
isConnected() → bool
isConnecting() → bool
joinContactEvents(String contactId) → void
joinMyEvents(String myId) → void
joinRoom(String bareRoom) → void
leaveContactEvents(String contactId) → void
leaveRoom(String bareRoom) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendFilePayload(File file, String channel) → void
sendPayload(String payload, String channel) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited