MessageGlobalReader class abstract

Implementers

Constructors

MessageGlobalReader()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
getChatMarkerMessages() → Stream<ChatMarkerMessage>
getChatMessages() → Stream<ChatMessage>
getPresenceMessages() → Stream<PresenceMessage>
getTypingMessages() → Stream<TypingIndicatorMessage>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited