BaseMessage class

Implementers
Annotations
  • @JsonSerializable.new()

Constructors

BaseMessage({required String id, required MessageType type, String? fromId, String? fromName, int? sendTime})
BaseMessage.fromJson(Map<String, dynamic> json)
factory
BaseMessage.fromString(String payload)
factory

Properties

dateTime → DateTime?
no setter
fromId → String?
final
fromName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTime → int?
final
type → MessageType
final

Methods

isChatMarkerEvent() → bool
isChatMessage() → bool
isInvitationEvent() → bool
isInvitationResponseEvent() → bool
isPresenceEvent() → bool
isTypingEvent() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

sendTimeFromJson(dynamic milliseconds) → int