ChatMarkerMessage class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ChatMarkerMessage({required String id, required MessageType type, required String referenceId, String? fromId, String? fromName, String? roomName, required ChatMarker status, int? sendTime})
ChatMarkerMessage.fromJson(Map<String, dynamic> json)
factory
ChatMarkerMessage.fromString(String payload)
factory

Properties

dateTime → DateTime?
no setterinherited
fromId → String?
finalinherited
fromName → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
referenceId → String
final
roomName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTime → int?
finalinherited
status → ChatMarker
final
type → MessageType
finalinherited

Methods

isChatMarkerEvent() → bool
inherited
isChatMessage() → bool
inherited
isInvitationEvent() → bool
inherited
isInvitationResponseEvent() → bool
inherited
isPresenceEvent() → bool
inherited
isTypingEvent() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited