ChatMessage class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ChatMessage({required String id, required MessageType type, String? fromId, String? fromName, String? toId, String? toName, required String text, required String roomId, MessageOriginality originality = MessageOriginality.original, String? attachment, String? thumbnail, String? originalId, String? originalMessage, int? sendTime, int? size, String? mime, double? longitude, double? latitude})
ChatMessage.fromJson(Map<String, dynamic> json)
factory
ChatMessage.fromString(String payload)
factory

Properties

attachment → String?
final
dateTime → DateTime?
no setterinherited
fromId → String?
finalinherited
fromName → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
latitude → double?
final
longitude → double?
final
mime → String?
final
originalId → String?
final
originality → MessageOriginality
final
originalMessage → String?
final
roomId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTime → int?
finalinherited
size → int?
final
text → String
final
thumbnail → String?
final
toId → String?
final
toName → String?
final
type → MessageType
finalinherited

Methods

copyWith({String? id, MessageType? type, String? fromId, String? fromName, String? toId, String? toName, String? text, String? roomId, MessageOriginality? originality, String? attachment, String? thumbnail, String? originalId, String? originalMessage, int? sendTime, int? size, String? mime, double? longitude, double? latitude}) → ChatMessage
isChatMarkerEvent() → bool
inherited
isChatMessage() → bool
inherited
isInvitationEvent() → bool
inherited
isInvitationResponseEvent() → bool
inherited
isPresenceEvent() → bool
inherited
isTypingEvent() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited