InvitationMessage class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

InvitationMessage({required String id, required MessageType type, String? fromId, String? fromName, String? fromAvatar, String? text, int? sendTime})
InvitationMessage.fromJson(Map<String, dynamic> json)
factory
InvitationMessage.fromString(dynamic payload)
factory

Properties

dateTime → DateTime?
no setterinherited
fromAvatar → String?
final
fromId → String?
finalinherited
fromName → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTime → int?
finalinherited
text → String?
final
type → MessageType
finalinherited

Methods

isChatMarkerEvent() → bool
inherited
isChatMessage() → bool
inherited
isInvitationEvent() → bool
inherited
isInvitationResponseEvent() → bool
inherited
isPresenceEvent() → bool
inherited
isTypingEvent() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited