TypingIndicatorMessage class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TypingIndicatorMessage({required String id, required MessageType type, required bool isTyping, required String roomId, String? fromId, String? fromName, int? sendTime})
TypingIndicatorMessage.fromJson(Map<String, dynamic> json)
factory
TypingIndicatorMessage.fromString(String payload)
factory

Properties

dateTime → DateTime?
no setterinherited
fromId → String?
finalinherited
fromName → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
isTyping → bool
final
roomId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTime → int?
finalinherited
type → MessageType
finalinherited

Methods

isChatMarkerEvent() → bool
inherited
isChatMessage() → bool
inherited
isInvitationEvent() → bool
inherited
isInvitationResponseEvent() → bool
inherited
isPresenceEvent() → bool
inherited
isTypingEvent() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

boolFromJson(dynamic value) → bool